Documentation
¶
Index ¶
- type AuditLog
- func (*AuditLog) Descriptor() ([]byte, []int)
- func (m *AuditLog) GetAuthenticationInfo() *AuthenticationInfo
- func (m *AuditLog) GetAuthorizationInfo() []*AuthorizationInfo
- func (m *AuditLog) GetMethodName() string
- func (m *AuditLog) GetNumResponseItems() int64
- func (m *AuditLog) GetRequest() *_struct.Struct
- func (m *AuditLog) GetRequestMetadata() *RequestMetadata
- func (m *AuditLog) GetResourceName() string
- func (m *AuditLog) GetResponse() *_struct.Struct
- func (m *AuditLog) GetServiceData() *any.Any
- func (m *AuditLog) GetServiceName() string
- func (m *AuditLog) GetStatus() *status.Status
- func (*AuditLog) ProtoMessage()
- func (m *AuditLog) Reset()
- func (m *AuditLog) String() string
- func (m *AuditLog) XXX_DiscardUnknown()
- func (m *AuditLog) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AuditLog) XXX_Merge(src proto.Message)
- func (m *AuditLog) XXX_Size() int
- func (m *AuditLog) XXX_Unmarshal(b []byte) error
- type AuthenticationInfo
- func (*AuthenticationInfo) Descriptor() ([]byte, []int)
- func (m *AuthenticationInfo) GetPrincipalEmail() string
- func (*AuthenticationInfo) ProtoMessage()
- func (m *AuthenticationInfo) Reset()
- func (m *AuthenticationInfo) String() string
- func (m *AuthenticationInfo) XXX_DiscardUnknown()
- func (m *AuthenticationInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AuthenticationInfo) XXX_Merge(src proto.Message)
- func (m *AuthenticationInfo) XXX_Size() int
- func (m *AuthenticationInfo) XXX_Unmarshal(b []byte) error
- type AuthorizationInfo
- func (*AuthorizationInfo) Descriptor() ([]byte, []int)
- func (m *AuthorizationInfo) GetGranted() bool
- func (m *AuthorizationInfo) GetPermission() string
- func (m *AuthorizationInfo) GetResource() string
- func (*AuthorizationInfo) ProtoMessage()
- func (m *AuthorizationInfo) Reset()
- func (m *AuthorizationInfo) String() string
- func (m *AuthorizationInfo) XXX_DiscardUnknown()
- func (m *AuthorizationInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AuthorizationInfo) XXX_Merge(src proto.Message)
- func (m *AuthorizationInfo) XXX_Size() int
- func (m *AuthorizationInfo) XXX_Unmarshal(b []byte) error
- type RequestMetadata
- func (*RequestMetadata) Descriptor() ([]byte, []int)
- func (m *RequestMetadata) GetCallerIp() string
- func (m *RequestMetadata) GetCallerSuppliedUserAgent() string
- func (*RequestMetadata) ProtoMessage()
- func (m *RequestMetadata) Reset()
- func (m *RequestMetadata) String() string
- func (m *RequestMetadata) XXX_DiscardUnknown()
- func (m *RequestMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RequestMetadata) XXX_Merge(src proto.Message)
- func (m *RequestMetadata) XXX_Size() int
- func (m *RequestMetadata) XXX_Unmarshal(b []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuditLog ¶
type AuditLog struct {
// The name of the API service performing the operation. For example,
// `"datastore.googleapis.com"`.
ServiceName string `protobuf:"bytes,7,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
// The name of the service method or operation.
// For API calls, this should be the name of the API method.
// For example,
//
// "google.datastore.v1.Datastore.RunQuery"
// "google.logging.v1.LoggingService.DeleteLog"
MethodName string `protobuf:"bytes,8,opt,name=method_name,json=methodName,proto3" json:"method_name,omitempty"`
// The resource or collection that is the target of the operation.
// The name is a scheme-less URI, not including the API service name.
// For example:
//
// "shelves/SHELF_ID/books"
// "shelves/SHELF_ID/books/BOOK_ID"
ResourceName string `protobuf:"bytes,11,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
// The number of items returned from a List or Query API method,
// if applicable.
NumResponseItems int64 `protobuf:"varint,12,opt,name=num_response_items,json=numResponseItems,proto3" json:"num_response_items,omitempty"`
// The status of the overall operation.
Status *status.Status `protobuf:"bytes,2,opt,name=status,proto3" json:"status,omitempty"`
// Authentication information.
AuthenticationInfo *AuthenticationInfo `protobuf:"bytes,3,opt,name=authentication_info,json=authenticationInfo,proto3" json:"authentication_info,omitempty"`
// Authorization information. If there are multiple
// resources or permissions involved, then there is
// one AuthorizationInfo element for each {resource, permission} tuple.
AuthorizationInfo []*AuthorizationInfo `protobuf:"bytes,9,rep,name=authorization_info,json=authorizationInfo,proto3" json:"authorization_info,omitempty"`
// Metadata about the operation.
RequestMetadata *RequestMetadata `protobuf:"bytes,4,opt,name=request_metadata,json=requestMetadata,proto3" json:"request_metadata,omitempty"`
// The operation request. This may not include all request parameters,
// such as those that are too large, privacy-sensitive, or duplicated
// elsewhere in the log record.
// It should never include user-generated data, such as file contents.
// When the JSON object represented here has a proto equivalent, the proto
// name will be indicated in the `@type` property.
Request *_struct.Struct `protobuf:"bytes,16,opt,name=request,proto3" json:"request,omitempty"`
// The operation response. This may not include all response elements,
// such as those that are too large, privacy-sensitive, or duplicated
// elsewhere in the log record.
// It should never include user-generated data, such as file contents.
// When the JSON object represented here has a proto equivalent, the proto
// name will be indicated in the `@type` property.
Response *_struct.Struct `protobuf:"bytes,17,opt,name=response,proto3" json:"response,omitempty"`
// Other service-specific data about the request, response, and other
// activities.
ServiceData *any.Any `protobuf:"bytes,15,opt,name=service_data,json=serviceData,proto3" json:"service_data,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Common audit log format for Google Cloud Platform API operations.
func (*AuditLog) Descriptor ¶
func (*AuditLog) GetAuthenticationInfo ¶
func (m *AuditLog) GetAuthenticationInfo() *AuthenticationInfo
func (*AuditLog) GetAuthorizationInfo ¶
func (m *AuditLog) GetAuthorizationInfo() []*AuthorizationInfo
func (*AuditLog) GetMethodName ¶
func (*AuditLog) GetNumResponseItems ¶
func (*AuditLog) GetRequest ¶
func (*AuditLog) GetRequestMetadata ¶
func (m *AuditLog) GetRequestMetadata() *RequestMetadata
func (*AuditLog) GetResourceName ¶
func (*AuditLog) GetResponse ¶
func (*AuditLog) GetServiceData ¶
func (*AuditLog) GetServiceName ¶
func (*AuditLog) ProtoMessage ¶
func (*AuditLog) ProtoMessage()
func (*AuditLog) XXX_DiscardUnknown ¶
func (m *AuditLog) XXX_DiscardUnknown()
func (*AuditLog) XXX_Marshal ¶
func (*AuditLog) XXX_Unmarshal ¶
type AuthenticationInfo ¶
type AuthenticationInfo struct {
// The email address of the authenticated user making the request.
PrincipalEmail string `protobuf:"bytes,1,opt,name=principal_email,json=principalEmail,proto3" json:"principal_email,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Authentication information for the operation.
func (*AuthenticationInfo) Descriptor ¶
func (*AuthenticationInfo) Descriptor() ([]byte, []int)
func (*AuthenticationInfo) GetPrincipalEmail ¶
func (m *AuthenticationInfo) GetPrincipalEmail() string
func (*AuthenticationInfo) ProtoMessage ¶
func (*AuthenticationInfo) ProtoMessage()
func (*AuthenticationInfo) Reset ¶
func (m *AuthenticationInfo) Reset()
func (*AuthenticationInfo) String ¶
func (m *AuthenticationInfo) String() string
func (*AuthenticationInfo) XXX_DiscardUnknown ¶
func (m *AuthenticationInfo) XXX_DiscardUnknown()
func (*AuthenticationInfo) XXX_Marshal ¶
func (m *AuthenticationInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AuthenticationInfo) XXX_Merge ¶
func (m *AuthenticationInfo) XXX_Merge(src proto.Message)
func (*AuthenticationInfo) XXX_Size ¶
func (m *AuthenticationInfo) XXX_Size() int
func (*AuthenticationInfo) XXX_Unmarshal ¶
func (m *AuthenticationInfo) XXX_Unmarshal(b []byte) error
type AuthorizationInfo ¶
type AuthorizationInfo struct {
// The resource being accessed, as a REST-style string. For example:
//
// bigquery.googlapis.com/projects/PROJECTID/datasets/DATASETID
Resource string `protobuf:"bytes,1,opt,name=resource,proto3" json:"resource,omitempty"`
// The required IAM permission.
Permission string `protobuf:"bytes,2,opt,name=permission,proto3" json:"permission,omitempty"`
// Whether or not authorization for `resource` and `permission`
// was granted.
Granted bool `protobuf:"varint,3,opt,name=granted,proto3" json:"granted,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Authorization information for the operation.
func (*AuthorizationInfo) Descriptor ¶
func (*AuthorizationInfo) Descriptor() ([]byte, []int)
func (*AuthorizationInfo) GetGranted ¶
func (m *AuthorizationInfo) GetGranted() bool
func (*AuthorizationInfo) GetPermission ¶
func (m *AuthorizationInfo) GetPermission() string
func (*AuthorizationInfo) GetResource ¶
func (m *AuthorizationInfo) GetResource() string
func (*AuthorizationInfo) ProtoMessage ¶
func (*AuthorizationInfo) ProtoMessage()
func (*AuthorizationInfo) Reset ¶
func (m *AuthorizationInfo) Reset()
func (*AuthorizationInfo) String ¶
func (m *AuthorizationInfo) String() string
func (*AuthorizationInfo) XXX_DiscardUnknown ¶
func (m *AuthorizationInfo) XXX_DiscardUnknown()
func (*AuthorizationInfo) XXX_Marshal ¶
func (m *AuthorizationInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AuthorizationInfo) XXX_Merge ¶
func (m *AuthorizationInfo) XXX_Merge(src proto.Message)
func (*AuthorizationInfo) XXX_Size ¶
func (m *AuthorizationInfo) XXX_Size() int
func (*AuthorizationInfo) XXX_Unmarshal ¶
func (m *AuthorizationInfo) XXX_Unmarshal(b []byte) error
type RequestMetadata ¶
type RequestMetadata struct {
// The IP address of the caller.
CallerIp string `protobuf:"bytes,1,opt,name=caller_ip,json=callerIp,proto3" json:"caller_ip,omitempty"`
// The user agent of the caller.
// This information is not authenticated and should be treated accordingly.
// For example:
//
// + `google-api-python-client/1.4.0`:
// The request was made by the Google API client for Python.
// + `Cloud SDK Command Line Tool apitools-client/1.0 gcloud/0.9.62`:
// The request was made by the Google Cloud SDK CLI (gcloud).
// + `AppEngine-Google; (+http://code.google.com/appengine; appid: s~my-project`:
// The request was made from the `my-project` App Engine app.
CallerSuppliedUserAgent string `` /* 134-byte string literal not displayed */
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Metadata about the request.
func (*RequestMetadata) Descriptor ¶
func (*RequestMetadata) Descriptor() ([]byte, []int)
func (*RequestMetadata) GetCallerIp ¶
func (m *RequestMetadata) GetCallerIp() string
func (*RequestMetadata) GetCallerSuppliedUserAgent ¶
func (m *RequestMetadata) GetCallerSuppliedUserAgent() string
func (*RequestMetadata) ProtoMessage ¶
func (*RequestMetadata) ProtoMessage()
func (*RequestMetadata) Reset ¶
func (m *RequestMetadata) Reset()
func (*RequestMetadata) String ¶
func (m *RequestMetadata) String() string
func (*RequestMetadata) XXX_DiscardUnknown ¶
func (m *RequestMetadata) XXX_DiscardUnknown()
func (*RequestMetadata) XXX_Marshal ¶
func (m *RequestMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RequestMetadata) XXX_Merge ¶
func (m *RequestMetadata) XXX_Merge(src proto.Message)
func (*RequestMetadata) XXX_Size ¶
func (m *RequestMetadata) XXX_Size() int
func (*RequestMetadata) XXX_Unmarshal ¶
func (m *RequestMetadata) XXX_Unmarshal(b []byte) error
Click to show internal directories.
Click to hide internal directories.